#include "ipstore"

IPStore::StoreMap IPStore::store;
bool IPStore::onoff = false;

int IPStore::target(struct in_addr clientip) {
    time_t now = time(0);

    // Weed out store. Done first, because the store should be up to date
    // for some decisions below.
    bool done = false;
    Mutex::lock(&store);
    while (!done) {
	done = true;
	for (StoreMap::iterator iter = store.begin();
	     iter != store.end();
	     iter++) {
	    if (now - ((*iter).second.lastaccess) > config.ipstoretimeout()) {
		if (config.debug()) {
		    done = false;
		    Timestamp tm((*iter).second.lastaccess);
		    debugmsg (Mstr(inet_ntoa(iter->first)) +
			      Mstr(" visited on ") + tm.desc() + ", erasing\n");
		}
		store.erase(iter);
		break;
	    }
	}
    }
    Mutex::unlock(&store);

    // Let's see if we know the client.
    if (store.count(clientip) > 0) {
	if (config.verbose()) {
	    Timestamp tm(store[clientip].lastaccess);
	    msg(Mstr("Client IP ") + Mstr(inet_ntoa(clientip)) +
		" last visited on " + tm.desc() + " and went to " +
		balancer.backend(store[clientip].targetbackend).description() +
		"\n");
	}
	return store[clientip].targetbackend;
    }
    return -1;
}
    
